#[repr(transparent)]pub struct Odd<T>(T)
where
T: ?Sized;Expand description
Wrapper type for odd integers.
These are frequently used in cryptography, e.g. as a modulus.
Tuple Fields
0: TImplementations
Sourceimpl<const LIMBS: usize> Odd<Int<LIMBS>>
impl<const LIMBS: usize> Odd<Int<LIMBS>>
Sourcepub const fn gcd_unsigned(&self, rhs: &Uint<LIMBS>) -> Odd<Uint<LIMBS>>
pub const fn gcd_unsigned(&self, rhs: &Uint<LIMBS>) -> Odd<Uint<LIMBS>>
Compute the greatest common divisor of self and rhs.
Sourcepub const fn gcd_unsigned_vartime(&self, rhs: &Uint<LIMBS>) -> Odd<Uint<LIMBS>>
pub const fn gcd_unsigned_vartime(&self, rhs: &Uint<LIMBS>) -> Odd<Uint<LIMBS>>
Compute the greatest common divisor of self and rhs.
Executes in variable time w.r.t. all input parameters.
Sourceimpl<T> Odd<T>
impl<T> Odd<T>
Sourceimpl<const LIMBS: usize> Odd<Uint<LIMBS>>
impl<const LIMBS: usize> Odd<Uint<LIMBS>>
Sourcepub const fn from_be_hex(hex: &str) -> Odd<Uint<LIMBS>>
pub const fn from_be_hex(hex: &str) -> Odd<Uint<LIMBS>>
Sourcepub const fn from_le_hex(hex: &str) -> Odd<Uint<LIMBS>>
pub const fn from_le_hex(hex: &str) -> Odd<Uint<LIMBS>>
Create a new Odd<Uint<LIMBS>> from the provided little endian hex string.
Panics
- if the hex is malformed or not zero-padded accordingly for the size.
- if the value is even.
Sourcepub const fn as_uint_ref(&self) -> &Odd<UintRef>
pub const fn as_uint_ref(&self) -> &Odd<UintRef>
Borrow this OddUint as a &OddUintRef.
Sourceimpl Odd<UintRef>
impl Odd<UintRef>
Sourcepub const fn to_uint_resize<const T: usize>(&self) -> Odd<Uint<T>>
pub const fn to_uint_resize<const T: usize>(&self) -> Odd<Uint<T>>
Construct an Odd<Uint<T>> from the unsigned integer value,
truncating the upper bits if the value is too large to be
represented.
Sourceimpl<const LIMBS: usize> Odd<Uint<LIMBS>>
impl<const LIMBS: usize> Odd<Uint<LIMBS>>
Sourcepub const fn gcd_unsigned(&self, rhs: &Uint<LIMBS>) -> Odd<Uint<LIMBS>>
pub const fn gcd_unsigned(&self, rhs: &Uint<LIMBS>) -> Odd<Uint<LIMBS>>
Compute the greatest common divisor of self and rhs.
Sourcepub const fn gcd_unsigned_vartime(&self, rhs: &Uint<LIMBS>) -> Odd<Uint<LIMBS>>
pub const fn gcd_unsigned_vartime(&self, rhs: &Uint<LIMBS>) -> Odd<Uint<LIMBS>>
Compute the greatest common divisor of self and rhs.
Executes in variable time w.r.t. all input parameters.